
package Shipment::Purolator::WSDLV2::Elements::ArrayOfSuggestedAddress;
$Shipment::Purolator::WSDLV2::Elements::ArrayOfSuggestedAddress::VERSION = '3.07';
use strict;
use warnings;

{ # BLOCK to scope variables

sub get_xmlns { 'http://purolator.com/pws/datatypes/v2' }

__PACKAGE__->__set_name('ArrayOfSuggestedAddress');
__PACKAGE__->__set_nillable(1);
__PACKAGE__->__set_minOccurs();
__PACKAGE__->__set_maxOccurs();
__PACKAGE__->__set_ref();
use base qw(
    SOAP::WSDL::XSD::Typelib::Element
    Shipment::Purolator::WSDLV2::Types::ArrayOfSuggestedAddress
);

}

1;

__END__

=pod

=encoding UTF-8

=head1 NAME

Shipment::Purolator::WSDLV2::Elements::ArrayOfSuggestedAddress

=head1 VERSION

version 3.07

=head1 DESCRIPTION

Perl data type class for the XML Schema defined element
ArrayOfSuggestedAddress from the namespace http://purolator.com/pws/datatypes/v2.

=head1 NAME

Shipment::Purolator::WSDLV2::Elements::ArrayOfSuggestedAddress

=head1 METHODS

=head2 new

 my $element = Shipment::Purolator::WSDLV2::Elements::ArrayOfSuggestedAddress->new($data);

Constructor. The following data structure may be passed to new():

 { # Shipment::Purolator::WSDLV2::Types::ArrayOfSuggestedAddress
   SuggestedAddress =>  { # Shipment::Purolator::WSDLV2::Types::SuggestedAddress
     Address =>  { # Shipment::Purolator::WSDLV2::Types::ShortAddress
       City =>  $some_value, # string
       Province =>  $some_value, # string
       Country =>  $some_value, # string
       PostalCode =>  $some_value, # string
     },
     ResponseInformation =>  { # Shipment::Purolator::WSDLV2::Types::ResponseInformation
       Errors =>  { # Shipment::Purolator::WSDLV2::Types::ArrayOfError
         Error =>  { # Shipment::Purolator::WSDLV2::Types::Error
           Code =>  $some_value, # string
           Description =>  $some_value, # string
           AdditionalInformation =>  $some_value, # string
         },
       },
       InformationalMessages =>  { # Shipment::Purolator::WSDLV2::Types::ArrayOfInformationalMessage
         InformationalMessage =>  { # Shipment::Purolator::WSDLV2::Types::InformationalMessage
           Code =>  $some_value, # string
           Message =>  $some_value, # string
         },
       },
     },
   },
 },

=head1 AUTHOR

Generated by SOAP::WSDL

=head1 AUTHOR

Andrew Baerg <baergaj@cpan.org>

=head1 COPYRIGHT AND LICENSE

This software is copyright (c) 2018 by Andrew Baerg.

This is free software; you can redistribute it and/or modify it under
the same terms as the Perl 5 programming language system itself.

=cut
